==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/de-if/admin/kits/general.php <==
<?php

return [
    'about_kits_title'                  => 'Über vordefinierte Kits',
    'about_kits_text'                   => 'Mit vordefinierten Kits kannst Du schnell eine Sammlung von Elementen (Assets, Lizenzen, etc.) an einen Benutzer ausgeben. Dies kann hilfreich sein, wenn Ihr Onboarding-Prozess über viele Nutzer hinweg einheitlich ist und alle Nutzer die gleichen Artikel erhalten.',
    'checkout'                          => 'Kit herausgeben ',
    'create_success'                    => 'Kit wurde erfolgreich erstellt.',
    'create'                            => 'Vordefiniertes Kit erstellen',
    'update'                            => 'Vordefiniertes Kit aktualisieren',
    'delete_success'                    => 'Kit wurde erfolgreich gelöscht.',
    'update_success'                    => 'Kit wurde erfolgreich aktualisiert.',
    'none_models'                       => 'Es gibt nicht genügend verfügbare Assets für :model zum Herausgeben. :qty sind erforderlich. ',
    'none_licenses'                     => 'Es gibt nicht genügend Lizenzen für :license zum Herausgeben. :qty sind erforderlich. ',
    'none_consumables'                  => 'Es gibt nicht genügend verfügbare Einheiten von :consumable zum Herausgeben. :qty sind erforderlich. ',
    'none_accessory'                    => 'Es gibt nicht genügend verfügbare Einheiten von :accessory zum Herausgeben. :qty werden benötigt. ',
    'append_accessory'                  => 'Zubehör anhängen',
    'update_appended_accessory'         => 'Angefügtes Zubehör aktualisieren',
    'append_consumable'                 => 'Verbrauchsmaterial anhängen',
    'update_appended_consumable'        => 'Angehängtes Verbrauchsmaterial aktualisieren',
    'append_license'                    => 'Lizenz anhängen',
    'update_appended_license'           => 'Angefügte Lizenz aktualisieren',
    'append_model'                      => 'Modell anhängen',
    'update_appended_model'             => 'Angehängtes Modell aktualisieren',
    'license_error'                     => 'Lizenz bereits mit Kit verbunden',
    'license_added_success'             => 'Die Lizenz wurde erfolgreich hinzugefügt',
    'license_updated'                   => 'Die Lizenz wurde erfolgreich aktualisiert',
    'license_none'                      => 'Die Lizenz existiert nicht',
    'license_detached'                  => 'Die Lizenz wurde erfolgreich gelöst',
    'consumable_added_success'          => 'Verbrauchsmaterial erfolgreich hinzugefügt',
    'consumable_updated'                => 'Verbrauchsmaterial wurde erfolgreich aktualisiert',
    'consumable_error'                  => 'Verbrauchsmaterial bereits mit Kit verbunden',
    'consumable_deleted'                => 'Löschen war erfolgreich',
    'consumable_none'                   => 'Verbrauchsmaterial existiert nicht',
    'consumable_detached'               => 'Verbrauchsmaterial wurde erfolgreich gelöst',
    'accessory_added_success'           => 'Zubehör erfolgreich hinzugefügt',
    'accessory_updated'                 => 'Zubehör wurde erfolgreich aktualisiert',
    'accessory_detached'                => 'Zubehör wurde erfolgreich getrennt',
    'accessory_error'                   => 'Zubehör bereits an Kit angeschlossen',
    'accessory_deleted'                 => 'Löschen war erfolgreich',
    'accessory_none'                    => 'Das Zubehör existiert nicht',
    'checkout_success'                  => 'Herausgabe war erfolgreich',
    'checkout_error'                    => 'Herausgabe Fehler',
    'kit_none'                          => 'Kit existiert nicht',
    'kit_created'                       => 'Kit wurde erfolgreich erstellt',
    'kit_updated'                       => 'Kit wurde erfolgreich aktualisiert',
    'kit_not_found'                     => 'Kit nicht gefunden',
    'kit_deleted'                       => 'Kit wurde erfolgreich gelöscht',
    'kit_model_updated'                 => 'Modell wurde erfolgreich aktualisiert',
    'kit_model_detached'                => 'Modell wurde erfolgreich gelöst',
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/de-if/admin/kits/general.php <==
<?php

return [
    'about_kits_title'                  => 'Über vordefinierte Kits',
    'about_kits_text'                   => 'Mit vordefinierten Kits kannst du schnell eine Sammlung von Elementen (Assets, Lizenzen, etc.) an einen Benutzer ausgeben. Dies kann hilfreich sein, wenn dein Onboarding-Prozess über viele Nutzer hinweg einheitlich ist und alle Nutzer die gleichen Artikel erhalten.',
    'checkout'                          => 'Kit herausgeben ',
    'create_success'                    => 'Kit wurde erfolgreich erstellt.',
    'create'                            => 'Vordefiniertes Kit erstellen',
    'update'                            => 'Vordefiniertes Kit aktualisieren',
    'delete_success'                    => 'Kit wurde erfolgreich gelöscht.',
    'update_success'                    => 'Kit wurde erfolgreich aktualisiert.',
    'none_models'                       => 'Es gibt nicht genügend verfügbare Assets für :model zum Herausgeben. :qty sind erforderlich. ',
    'none_licenses'                     => 'Es gibt nicht genügend Lizenzen für :license zum Herausgeben. :qty sind erforderlich. ',
    'none_consumables'                  => 'Es gibt nicht genügend verfügbare Einheiten von :consumable zum Herausgeben. :qty sind erforderlich. ',
    'none_accessory'                    => 'Es gibt nicht genügend verfügbare Einheiten von :accessory zum Herausgeben. :qty werden benötigt. ',
    'append_accessory'                  => 'Zubehör anhängen',
    'update_appended_accessory'         => 'Angefügtes Zubehör aktualisieren',
    'append_consumable'                 => 'Verbrauchsmaterial anhängen',
    'update_appended_consumable'        => 'Angehängtes Verbrauchsmaterial aktualisieren',
    'append_license'                    => 'Lizenz anhängen',
    'update_appended_license'           => 'Angefügte Lizenz aktualisieren',
    'append_model'                      => 'Modell anhängen',
    'update_appended_model'             => 'Angehängtes Modell aktualisieren',
    'license_error'                     => 'Lizenz bereits mit Kit verbunden',
    'license_added_success'             => 'Die Lizenz wurde erfolgreich hinzugefügt',
    'license_updated'                   => 'Die Lizenz wurde erfolgreich aktualisiert',
    'license_none'                      => 'Die Lizenz existiert nicht',
    'license_detached'                  => 'Die Lizenz wurde erfolgreich gelöst',
    'consumable_added_success'          => 'Verbrauchsmaterial erfolgreich hinzugefügt',
    'consumable_updated'                => 'Verbrauchsmaterial wurde erfolgreich aktualisiert',
    'consumable_error'                  => 'Verbrauchsmaterial bereits mit Kit verbunden',
    'consumable_deleted'                => 'Löschen war erfolgreich',
    'consumable_none'                   => 'Verbrauchsmaterial existiert nicht',
    'consumable_detached'               => 'Verbrauchsmaterial wurde erfolgreich gelöst',
    'accessory_added_success'           => 'Zubehör erfolgreich hinzugefügt',
    'accessory_updated'                 => 'Zubehör wurde erfolgreich aktualisiert',
    'accessory_detached'                => 'Zubehör wurde erfolgreich getrennt',
    'accessory_error'                   => 'Zubehör bereits an Kit angeschlossen',
    'accessory_deleted'                 => 'Löschen war erfolgreich',
    'accessory_none'                    => 'Das Zubehör existiert nicht',
    'checkout_success'                  => 'Herausgabe war erfolgreich',
    'checkout_error'                    => 'Herausgabe Fehler',
    'kit_none'                          => 'Kit existiert nicht',
    'kit_created'                       => 'Kit wurde erfolgreich erstellt',
    'kit_updated'                       => 'Kit wurde erfolgreich aktualisiert',
    'kit_not_found'                     => 'Kit nicht gefunden',
    'kit_deleted'                       => 'Kit wurde erfolgreich gelöscht',
    'kit_model_updated'                 => 'Modell wurde erfolgreich aktualisiert',
    'kit_model_detached'                => 'Modell wurde erfolgreich gelöst',
    'model_already_attached'            => 'Dieses Modell ist bereits einem Kit zugewiesen',
];
